What is a TAP?
--------------

A TAP (TUF Augmentation Proposal) is a design document providing information to
the TUF community, or describing a new feature for TUF or its processes or
environment.  We intend TAPs to be the primary mechanisms for proposing major
new features, for collecting community input on an issue, and for documenting
the design decisions that have gone into TUF.

Please visit the `TAPs GitHub repo <https://github.com/theupdateframework/taps>`_
to review design changes that have been proposed to date, or to submit
your own new feature.
